summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoRect.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoRect.h')
-rw-r--r--lib/kofficecore/KoRect.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/kofficecore/KoRect.h b/lib/kofficecore/KoRect.h
index dfc63946..b4289088 100644
--- a/lib/kofficecore/KoRect.h
+++ b/lib/kofficecore/KoRect.h
@@ -21,12 +21,12 @@
#include "KoPoint.h"
#include "KoSize.h"
-#include <qrect.h>
+#include <tqrect.h>
#include "koffice_export.h"
/**
* A rect whose coordinates are floating-point values ( "double"s ).
* The API isn't documented, it's a perfect mirror of QRect.
*/
class KOFFICEUI_EXPORT KoRect {
@@ -42,9 +42,9 @@ public:
~KoRect() {}
bool isNull() const { return m_tl == m_br; }
// Like QRect, a null KoRect is empty.
bool isEmpty() const { return m_tl.x() > m_br.x() || m_tl.y() > m_br.y() || isNull(); }
// Unlike QRect, a null KoRect is valid (0-sized).
bool isValid() const { return m_tl.x() <= m_br.x() && m_tl.y() <= m_br.y(); }
KoRect normalize() const;
@@ -108,20 +108,20 @@ public:
* Note that for KoRect(0, 0, 100, 100) the KoPoint(0, 0) as well as KoPoint(100, 100) are
* mathmatically contained in the rect, this in contrary to pixel based rectangles.
*/
- bool contains(const KoPoint &p) const;
+ bool tqcontains(const KoPoint &p) const;
/// Helper function for the above function.
- bool contains(const double &x, const double &y) const;
+ bool tqcontains(const double &x, const double &y) const;
/// Helper function for the above function.
- bool contains(const KoRect &r) const;
+ bool tqcontains(const KoRect &r) const;
KoRect unite(const KoRect &r) const;
KoRect intersect(const KoRect &r) const;
bool intersects(const KoRect &r) const;
- KoRect transform(const QWMatrix &m) const;
+ KoRect transform(const TQWMatrix &m) const;
KoRect translate(double dx, double dy) const;
- QRect toQRect() const;
- static KoRect fromQRect( const QRect &rect );
+ TQRect toTQRect() const;
+ static KoRect fromTQRect( const TQRect &rect );
private:
KoPoint m_tl, m_br;
@@ -141,7 +141,7 @@ inline kdbgstream operator<<( kdbgstream str, const KoRect & r ) { str << "[" <
inline kndbgstream operator<<( kndbgstream str, const KoRect & ) { return str; }
/** Show the rectangles that form a region (use as a standalone statement) */
-#define DEBUGREGION(reg) { QMemArray<QRect>rs=reg.rects(); for (int i=0;i<rs.size();++i) \
+#define DEBUGREGION(reg) { TQMemArray<TQRect>rs=reg.rects(); for (int i=0;i<rs.size();++i) \
kdDebug()<<" "<<DEBUGRECT(rs[i] )<<endl; }
// You can now use kdDebug() << theregion << endl; (kdebug.h)
@@ -21,12 +21,12 @@
/**
* A rect whose coordinates are floating-point values ( "double"s ).
- * The API isn't documented, it's a perfect mirror of QRect.
+ * The API isn't documented, it's a perfect mirror of TQRect.
*/
class KOFFICEUI_EXPORT KoRect {
@@ -42,9 +42,9 @@ public:
~KoRect() {}
bool isNull() const { return m_tl == m_br; }
- // Like QRect, a null KoRect is empty.
+ // Like TQRect, a null KoRect is empty.
bool isEmpty() const { return m_tl.x() > m_br.x() || m_tl.y() > m_br.y() || isNull(); }
@@ -42,9 +42,9 @@ public:
bool isEmpty() const { return m_tl.x() > m_br.x() || m_tl.y() > m_br.y() || isNull(); }
- // Unlike QRect, a null KoRect is valid (0-sized).
+ // Unlike TQRect, a null KoRect is valid (0-sized).
bool isValid() const { return m_tl.x() <= m_br.x() && m_tl.y() <= m_br.y(); }
KoRect normalize() const;